@@ -7,8 +7,10 @@ from .transformers.collector import Collector
 from .transformers.compileFinalFiles import CompileFinalFiles
 from .transformers.constructDynamicCodeObjTransformer import ConstructDynamicCodeObject
 from .transformers.encodeStringsTransformer import EncodeStrings
+from .transformers.floatsToComplex import FloatsToComplex
 from .transformers.fstrToFormatTransformer import FstringsToFormatSequence
 from .transformers.intObfuscatorTransformer import IntObfuscator
+from .transformers.logicTransformer import LogicTransformer
 from .transformers.memberRenamerTransformer import MemberRenamer
 from .transformers.packPyz import PackInPyz
 from .transformers.removeTypeHintsTransformer import RemoveTypeHints
@@ -22,9 +24,11 @@ all_config_segments = []
 all_transformers = [
     x()
     for x in [
+        LogicTransformer,
         RemoveTypeHints,
         FstringsToFormatSequence,
         EncodeStrings,
+        FloatsToComplex,
         IntObfuscator,
         MemberRenamer,
         ReplaceAttribs,
