@@ -16,7 +16,9 @@ class MemberRenamer(Transformer):
                 "'counter' is a variable incrementing with each name generated\n"
                 "'kind' is either 'method', 'var', 'arg' or 'class', depending on the current element\n"
                 "'get_counter(name)' is a method that increments a counter behind 'name', and returns its current "
-                "value",
+                "value\n"
+                "'random_identifier(length)' returns a valid python identifier, according to "
+                "https://docs.python.org/3/reference/lexical_analysis.html#identifiers",
                 "f'{kind}{get_counter(kind)}'",
             ),
         )
@@ -24,6 +26,7 @@ class MemberRenamer(Transformer):
     def transform(self, ast: AST, current_file_name, all_asts, all_file_names) -> AST:
         generator = MappingGenerator(self.config["rename_format"].value)
         generator.visit(ast)
+        # generator.print_mappings()
         MappingApplicator(generator.mappings).visit(ast)
         if all_asts is not None:
             mappings1 = {}
